[pve-devel] [PATCH manager] VZDump: switch ha managed check from enabled to started

Thomas Lamprecht t.lamprecht at proxmox.com
Tue Nov 22 14:45:02 CET 2016


Signed-off-by: Thomas Lamprecht <t.lamprecht at proxmox.com>
---
 PVE/VZDump.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/PVE/VZDump.pm b/PVE/VZDump.pm
index cf480ad..0bd942b 100644
--- a/PVE/VZDump.pm
+++ b/PVE/VZDump.pm
@@ -770,9 +770,9 @@ sub exec_backup_task {
 	die "unable to find VM '$vmid'\n" if !$plugin;
 
 	# for now we deny backups of a running ha managed service in *stop* mode
 	# as it interferes with the HA stack (enabled services should not stop).
 	if ($opts->{mode} eq 'stop' &&
-	    PVE::HA::Config::vm_is_ha_managed($vmid, 'enabled'))
+	    PVE::HA::Config::vm_is_ha_managed($vmid, 'started'))
 	{
 	    die "Cannot execute a backup with stop mode on a HA managed and".
 		" enabled Service. Use snapshot mode or disable the Service.\n";
@@ -770,9 +770,9 @@ sub exec_backup_task {
 
 	# for now we deny backups of a running ha managed service in *stop* mode
-	# as it interferes with the HA stack (enabled services should not stop).
+	# as it interferes with the HA stack (started services should not stop).
 	if ($opts->{mode} eq 'stop' &&
-- 
2.1.4





More information about the pve-devel mailing list